diff libpurple/notify.h @ 32379:0cc718e10344

Actually commit the purple_notify_user_info_prepend_pair_plaintext function. I think I left it off my previous commit? Sorry. And rename purple_notify_user_info_prepend_pair to purple_notify_user_info_prepend_pair_html_html
author Mark Doliner <mark@kingant.net>
date Mon, 22 Aug 2011 06:32:44 +0000
parents 6283c0f2b02f
children 5aa171c8776b
line wrap: on
line diff
--- a/libpurple/notify.h	Mon Aug 22 06:25:23 2011 +0000
+++ b/libpurple/notify.h	Mon Aug 22 06:32:44 2011 +0000
@@ -489,19 +489,16 @@
 void purple_notify_user_info_add_pair_plaintext(PurpleNotifyUserInfo *user_info, const char *label, const char *value);
 
 /**
- * Prepend a label/value pair to a PurpleNotifyUserInfo object
- *
- * @param user_info  The PurpleNotifyUserInfo
- * @param label      A label, which for example might be displayed by a
- *                   UI with a colon after it ("Status:"). Do not include
- *                   a colon.  If NULL, value will be displayed without a
- *                   label.
- * @param value      The value, which might be displayed by a UI after
- *                   the label.  If NULL, label will still be displayed;
- *                   the UI should then treat label as independent and not
- *                   include a colon if it would otherwise.
+ * Like purple_notify_user_info_add_pair_html, but the pair is inserted
+ * at the beginning of the list.
  */
-void purple_notify_user_info_prepend_pair(PurpleNotifyUserInfo *user_info, const char *label, const char *value);
+void purple_notify_user_info_prepend_pair_html(PurpleNotifyUserInfo *user_info, const char *label, const char *value);
+
+/**
+ * Like purple_notify_user_info_prepend_pair_html, but value should be plaintext
+ * and will be escaped using g_markup_escape_text().
+ */
+void purple_notify_user_info_prepend_pair_plaintext(PurpleNotifyUserInfo *user_info, const char *label, const char *value);
 
 #if !(defined PURPLE_DISABLE_DEPRECATED) || (defined _PURPLE_NOTIFY_C_)
 /**
@@ -525,9 +522,10 @@
  * If added to a PurpleNotifyUserInfo object, this should not be free()'d,
  * as PurpleNotifyUserInfo will do so when destroyed.
  * purple_notify_user_info_add_pair_html(),
  * purple_notify_user_info_add_pair_plaintext() and
  * purple_notify_user_info_prepend_pair() are convenience methods for
  * creating entries and adding them to a PurpleNotifyUserInfo.
  *
  * @param label  A label, which for example might be displayed by a UI
  *               with a colon after it ("Status:"). Do not include a
@@ -525,9 +522,10 @@
  * as PurpleNotifyUserInfo will do so when destroyed.
  * purple_notify_user_info_add_pair_html(),
- * purple_notify_user_info_add_pair_plaintext() and
- * purple_notify_user_info_prepend_pair() are convenience methods for
- * creating entries and adding them to a PurpleNotifyUserInfo.
+ * purple_notify_user_info_add_pair_plaintext(),
+ * purple_notify_user_info_prepend_pair_html() and
+ * purple_notify_user_info_prepend_pair_plaintext() are convenience
+ * methods for creating entries and adding them to a PurpleNotifyUserInfo.
  *
  * @param label  A label, which for example might be displayed by a UI